Enum wallet::descriptor::DeductionError[][src]

pub enum DeductionError {
    IncompleteInformation,
    UnsupportedWitnessVersion(WitnessVersion),
}

Errors that happens during Category::deduce process

Variants

IncompleteInformation

For P2SH scripts we need to know whether it is created for the witness-containing spending transaction input, i.e. whether its redeem script will have a witness structure, or not. If this information was not provided, this error is returned.

UnsupportedWitnessVersion(WitnessVersion)

Here we support only version 0 and 1 of the witness, otherwise this error is returned