Enum wallet::descriptor::Error [−][src]
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Can’t deserealized public key from bitcoin script push op code
Wrong witness version, may be you need to upgrade used library version
PolicyCompilation(CompilerError)Policy compilation error
An uncompressed key can’t be used in a SegWit script context
Descriptor string parsing error