Enum wallet::descriptor::SingleSig[][src]

#[non_exhaustive]pub enum SingleSig {
    Pubkey(DescriptorSinglePub),
    XPubDerivable(DerivationComponents),
}

Variants (Non-exhaustive)

Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

Single known public key

XPubDerivable(DerivationComponents)

Public key range with deterministic derivation that can be derived from a known extended public key without private key

Implementations

impl SingleSig[src]

pub fn count(&self) -> u32[src]