Struct wallet::descriptor::ScriptTemplate [−][src]
Allows creating templates for native bitcoin scripts with embedded key generator templates. May be useful for creating descriptors in situations where target script can’t be deterministically represented by miniscript, for instance for Lightning network-specific transaction outputs
Implementations
impl<Pk> ScriptTemplate<Pk> where
Pk: MiniscriptKey + DerivePublicKey + StrictEncode + StrictDecode + FromStr,
<Pk as FromStr>::Err: Display, [src]
Pk: MiniscriptKey + DerivePublicKey + StrictEncode + StrictDecode + FromStr,
<Pk as FromStr>::Err: Display,
pub fn translate_pk(
&self,
child_index: UnhardenedIndex
) -> ScriptTemplate<PublicKey>[src]
&self,
child_index: UnhardenedIndex
) -> ScriptTemplate<PublicKey>