Enum wallet::psbt::SigningError[][src]

pub enum SigningError {
    WrongInputTxid {
        index: usize,
        non_witness_utxo_txid: Txid,
        txid: Txid,
    },
    SigHashType(usizeSigHashType),
    PubkeyMismatch {
        provided: PublicKey,
        derived: PublicKey,
    },
    NoPrevoutScript(usize),
    NoWitnessScript(usize),
    NonWitnessInput(usize),
    SecpPrivkeyDerivation(usize),
    ScriptPubkeyMismatch(usize),
    WrongTweakLength {
        input: usize,
        len: usize,
    },
    TweakFailure(usizePublicKey),
}

Variants

WrongInputTxid

Provided non_witness_utxo TXID {non_witness_utxo_txid} does not match prev_out {txid} from the transaction input #{index}

Fields of WrongInputTxid

index: usizenon_witness_utxo_txid: Txidtxid: Txid
SigHashType(usizeSigHashType)

Input #{0} requires custom sighash type {1}, while only SIGHASH_ALL is allowed

PubkeyMismatch

Public key {provided} provided with PSBT input does not match public key {derived} derived from the supplied private key using derivation path from that input

Fields of PubkeyMismatch

provided: PublicKeyderived: PublicKey
NoPrevoutScript(usize)

No redeem or witness script specified for input #{0}

NoWitnessScript(usize)

Input #{0} spending witness output does not contain witness script source

NonWitnessInput(usize)

Input #{0} must be a witness input since it is supplied with witness_utxo data and does not have non_witness_utxo

SecpPrivkeyDerivation(usize)

Unable to derive private key with a given derivation path: elliptic curve prime field order (p) overflow or derivation resulting at the point-at-infinity.

ScriptPubkeyMismatch(usize)

scriptPubkey from previous output does not match witness or redeem script from the same input #{0} supplied in PSBT

WrongTweakLength

Wrong pay-to-contract public key tweak data length in input #{input}: {len} bytes instead of 32

Fields of WrongTweakLength

input: usizelen: usize
TweakFailure(usizePublicKey)

Error applying tweak matching public key {1} from input #{0}: the tweak value is either a modulo-negation of the original private key, or it leads to elliptic curve prime field order (p) overflow