Struct wallet::psbt::Output [−][src]
A key-value map for an output of the corresponding index in the unsigned transaction.
Fields
redeem_script: Option<Script>The redeem script for this output.
witness_script: Option<Script>The witness script for this output.
bip32_derivation: BTreeMap<PublicKey, (Fingerprint, DerivationPath)>A map from public keys needed to spend this output to their corresponding master key fingerprints and derivation paths.
proprietary: BTreeMap<ProprietaryKey<u8>, Vec<u8, Global>>Proprietary key-value pairs for this output.
unknown: BTreeMap<Key, Vec<u8, Global>>Unknown key-value pairs for this output.