Struct wallet::psbt::ProprietaryKey [−][src]
Proprietary keys (i.e. keys starting with 0xFC byte) with their internal structure according to BIP 174.
Fields
prefix: Vec<u8, Global>Proprietary type prefix used for grouping together keys under some application and avoid namespace collision
subtype: SubtypeCustom proprietary subtype
key: Vec<u8, Global>Additional key bytes (like serialized public key data etc)
Implementations
impl<Subtype> ProprietaryKey<Subtype> where
Subtype: Copy + From<u8> + Into<u8>, [src]
Subtype: Copy + From<u8> + Into<u8>,
pub fn from_key(key: Key) -> Result<ProprietaryKey<Subtype>, Error>[src]
Constructs ProprietaryKey from Key; returns
Error::InvalidProprietaryKey if key do not starts with 0xFC byte
pub fn to_key(&self) -> Key[src]
Constructs full Key corresponding to this proprietary key type