Enum wallet::script::WitnessVersion [−][src]
Version of the WitnessProgram: first byte of scriptPubkey in
transaction output for transactions starting with opcodes ranging from 0
to 16 (inclusive).
Structure helps to limit possible version of the witness according to the
specification; if a plain u8 type will be used instead it will mean that
version > 16, which is incorrect.
Variants
Current, initial version of Witness Program. Used for P2WPKH and P2WPK outputs
Forthcoming second version of Witness Program, which (most probably) will be used for Taproot
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program
Future (unsupported) version of Witness Program