Struct wallet::script::LockScript [−][src]
Script whose knowledge is required for spending some specific transaction output. This is the deepest nested version of Bitcoin script containing no hashes of other scripts, including P2SH redeemScript hashes or witnessProgram (hash or witness script), or public key hashes
Implementations
impl LockScript[src]
pub fn extract_pubkeyset<Ctx>(
&self
) -> Result<BTreeSet<PublicKey>, PubkeyParseError> where
Ctx: ScriptContext, [src]
&self
) -> Result<BTreeSet<PublicKey>, PubkeyParseError> where
Ctx: ScriptContext,
Returns set of unique public keys from the script; fails on public key hash
pub fn extract_pubkey_hash_set<Ctx>(
&self
) -> Result<(BTreeSet<PublicKey>, BTreeSet<PubkeyHash>), PubkeyParseError> where
Ctx: ScriptContext, [src]
&self
) -> Result<(BTreeSet<PublicKey>, BTreeSet<PubkeyHash>), PubkeyParseError> where
Ctx: ScriptContext,
Returns tuple of two sets: one for unique public keys and one for unique hash values, extracted from the script
pub fn extract_pubkeys_and_hashes<Ctx>(
&self
) -> Result<(Vec<PublicKey>, Vec<PubkeyHash>), PubkeyParseError> where
Ctx: ScriptContext, [src]
&self
) -> Result<(Vec<PublicKey>, Vec<PubkeyHash>), PubkeyParseError> where
Ctx: ScriptContext,
Returns tuple with two vectors: one for public keys and one for public key hashes present in the script; if any of the keys or hashes has more than a single occurrence it returns all occurrences for each of them
pub fn extract_pubkeys<Ctx>(&self) -> Result<Vec<PublicKey>, PubkeyParseError> where
Ctx: ScriptContext, [src]
Ctx: ScriptContext,
Returns all public keys found in the script; fails on public key hash. If the key present multiple times in the script it returns all occurrences.
pub fn replace_pubkeys<Ctx, Fpk>(
&self,
processor: Fpk
) -> Result<Self, PubkeyParseError> where
Ctx: ScriptContext,
Fpk: Fn(&PublicKey) -> PublicKey, [src]
&self,
processor: Fpk
) -> Result<Self, PubkeyParseError> where
Ctx: ScriptContext,
Fpk: Fn(&PublicKey) -> PublicKey,
Replaces pubkeys using provided matching function; does not fail on public key hashes.
pub fn replace_pubkeys_and_hashes<Ctx, Fpk, Fpkh>(
&self,
key_processor: Fpk,
hash_processor: Fpkh
) -> Result<Self, PubkeyParseError> where
Ctx: ScriptContext,
Fpk: Fn(&PublicKey) -> PublicKey,
Fpkh: Fn(&Hash) -> Hash, [src]
&self,
key_processor: Fpk,
hash_processor: Fpkh
) -> Result<Self, PubkeyParseError> where
Ctx: ScriptContext,
Fpk: Fn(&PublicKey) -> PublicKey,
Fpkh: Fn(&Hash) -> Hash,
Replaces public keys and public key hashes using provided matching functions.