Trait wallet::script::ToScripts [−][src]
Script set generation from public keys or a given LockScript (with
TapScript support planned for the future).
Script set generation from public keys or a given LockScript (with
TapScript support planned for the future).
fn to_sig_script(&self, strategy: Category) -> SigScript[src]fn to_witness(&self, strategy: Category) -> Option<Witness>[src]fn to_scripts(&self, strategy: Category) -> ScriptSet[src]impl ToScripts for PublicKey[src]fn to_sig_script(&self, strategy: Category) -> SigScript[src]fn to_witness(&self, strategy: Category) -> Option<Witness>[src]impl ToScripts for PublicKey[src]fn to_sig_script(&self, strategy: Category) -> SigScript[src]fn to_witness(&self, strategy: Category) -> Option<Witness>[src]impl ToScripts for LockScript[src]fn to_sig_script(&self, strategy: Category) -> SigScript[src]fn to_witness(&self, strategy: Category) -> Option<Witness>[src]