Struct wallet::Psbt [−][src]
A Partially Signed Transaction.
Fields
global: GlobalThe key-value pairs for all global data.
inputs: Vec<Input, Global>The corresponding key-value map for each input in the unsigned transaction.
outputs: Vec<Output, Global>The corresponding key-value map for each output in the unsigned transaction.
Implementations
impl PartiallySignedTransaction[src]
pub fn from_unsigned_tx(
tx: Transaction
) -> Result<PartiallySignedTransaction, Error>[src]
tx: Transaction
) -> Result<PartiallySignedTransaction, Error>
Create a PartiallySignedTransaction from an unsigned transaction, error if not unsigned
pub fn extract_tx(self) -> Transaction[src]
Extract the Transaction from a PartiallySignedTransaction by filling in the available signature information in place.
pub fn merge(&mut self, other: PartiallySignedTransaction) -> Result<(), Error>[src]
Attempt to merge with another PartiallySignedTransaction.