Struct wallet::ScriptSet [−][src]
Scripting data for both transaction output and spending transaction input parts that can be generated from some complete bitcoin Script (LockScript) or public key using particular [ConversionStrategy]
Fields
pubkey_script: PubkeyScriptsig_script: SigScriptwitness_script: Option<Witness>Implementations
impl ScriptSet[src]
pub fn has_witness(&self) -> bool[src]
Detects whether the structure contains witness data
pub fn is_witness_sh(&self) -> bool[src]
Detects whether the structure is either P2SH-P2WPKH or P2SH-P2WSH
pub fn transmutate(&mut self, use_witness: bool) -> bool[src]
Tries to convert witness-based script structure into pre-SegWit – and
vice verse. Returns true if the conversion is possible and was
successful, false if the conversion is impossible; in the later case
the self is not changed. The conversion is impossible in the following
cases:
- for P2SH-P2WPKH or P2SH-P2WPSH variants (can be detected with ScriptSet::is_witness_sh function)
- for scripts that are internally inconsistent